======
Sphinx
======

The Sphinx contrib plugin adds a directive that can be used to document
extensions to the Henson command line interface.

.. autoclass:: henson.contrib.sphinx.HensonCLIDirective

For full details of the options support by the ``hensoncli`` directive, please
refer to the
`sphinxcontrib-autoprogram documentation <https://pythonhosted.org/sphinxcontrib-autoprogram/#additional-options-for-autoprogram>`_.
